==> ngs_test_utils-0.0.3-py3-none-any.whl: ngs_test_utils/testcase/gtf.py <==
"""Test utilities for GTF files."""
import pybedtools as pbt


class GtfTestCaseMixin:
    """Mixin for manipulation of GTF files in tests."""

    def create_gtf_attrs(self, **kwargs):
        """Create 9th column in GTF file - attributes."""
        attrs = ""
        for name, value in kwargs.items():
            attrs += '{} "{}"; '.format(name, value)

        attrs = attrs.strip()
        if attrs:
            return attrs
        else:
            return "."

    def make_gtf_interval(
        self,
        seqname="chr1",
        source="UCSC",
        feature="exon",
        start=1,
        end=1000,
        score=1,
        strand="+",
        frame=".",
        **kwargs,
    ):
        """Create GTF interval."""
        attrs = self.create_gtf_attrs(**kwargs)
        # GTF is 1 based so start+gtf=start_python + 1
        # GTF does include end coordinate, but Python does not, so end_gtf == end_python
        data = [seqname, source, feature, start + 1, end, score, strand, frame, attrs]
        return pbt.create_interval_from_list(data)

    def make_gtf(self, intervals):
        """Create GTF file from a list of lists.

        Data should be a list of pbt.Interval objects or dicts.
        """
        fname = self.get_filename(extension="gtf")

        if isinstance(intervals[0], dict):
            intervals = [self.make_gtf_interval(**interval) for interval in intervals]

        pbt.BedTool(interval for interval in intervals).saveas(fname)

        return fname

==> ngs_test_utils-0.0.5-py3-none-any.whl: ngs_test_utils/testcase/gtf.py <==
"""Test utilities for GTF files."""
import pybedtools as pbt


class GtfTestCaseMixin:
    """Mixin for manipulation of GTF files in tests."""

    def create_gtf_attrs(self, **kwargs):
        """Create 9th column in GTF file - attributes."""
        attrs = ""
        for name, value in kwargs.items():
            attrs += '{} "{}"; '.format(name, value)

        attrs = attrs.strip()
        if attrs:
            return attrs
        else:
            return "."

    def make_gtf_interval(
        self,
        seqname="chr1",
        source="UCSC",
        feature="exon",
        start=1,
        end=1000,
        score=1,
        strand="+",
        frame=".",
        **kwargs,
    ):
        """Create GTF interval."""
        attrs = self.create_gtf_attrs(**kwargs)
        # GTF is 1 based so start+gtf=start_python + 1
        # GTF does include end coordinate, but Python does not, so end_gtf == end_python
        data = [seqname, source, feature, start + 1, end, score, strand, frame, attrs]
        return pbt.create_interval_from_list(data)

    def make_gtf(self, intervals, sort=False):
        """Create GTF file from a list of lists.

        Data should be a list of pbt.Interval objects or dicts.
        """
        fname = self.get_filename(extension="gtf")

        if isinstance(intervals[0], dict):
            intervals = [self.make_gtf_interval(**interval) for interval in intervals]

        gtf = pbt.BedTool(interval for interval in intervals).saveas(fname)
        if sort:
            gtf.sort().saveas(fname)

        return fname
